You need to login to use Digicloud-CLI

You need to have a Digicloud account to use the Digicloud CLI.
To create your account please visit: https://digicloud.ir

If you forgot your password, please visit https://console.digicloud.ir/auth/forgot-password to recover you account

Examples:

You can simply login to your account:
$ digicloud account login

And later logout from your account:
$ digicloud account logout



